@@ -143,6 +143,13 @@ gboolean janus_flags_is_set(janus_flags *flags, gsize flag);
  * @note A failure may indicate that creating any of the subdirectories failed: some may still have been created */
 int janus_mkdir(const char *dir, mode_t mode);
 
+/*! \brief Helper to convert \c path relative to \c base_dir to absolute path.
+ *  If \c path already represents absolute path then just g_strdup it.
+ * @param[in] base_dir Path which will be prepended to \c path if it's relative
+ * @param[in] path Some relative or absolute path
+ * @returns g_strdup'ed absolute path. Should be freed with g_free() when no longer needed */
+gchar *janus_make_absolute_path(const gchar *base_dir, const gchar *path);
+
 /*! \brief Ugly and dirty helper to quickly get the payload type associated with a codec in an SDP
  * @param sdp The SDP to parse
  * @param codec The codec to look for
